[jbosscache-commits] JBoss Cache SVN: r7823 - in core/branches/flat/src: test/java/org/horizon/loader/bdbje and 1 other directory.

jbosscache-commits at lists.jboss.org jbosscache-commits at lists.jboss.org
Mon Mar 2 13:52:30 EST 2009


Author: adriancole
Date: 2009-03-02 13:52:30 -0500 (Mon, 02 Mar 2009)
New Revision: 7823

Modified:
   core/branches/flat/src/main/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfig.java
   core/branches/flat/src/test/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfigTest.java
Log:
changed location to be consistent with FileCacheStore

Modified: core/branches/flat/src/main/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfig.java
===================================================================
--- core/branches/flat/src/test/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfigTest.java	2009-03-02 18:47:12 UTC (rev 7822)
+++ core/branches/flat/src/test/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfigTest.java	2009-03-02 18:52:30 UTC (rev 7823)
@@ -56,6 +56,11 @@
    }
 
    @Test
+   public void testGetLocationDefault() {
+      assert config.getLocation().equals("Horizon-BdbjeCacheStore");
+   }
+
+   @Test
    public void testSetLocation() {
       config.setLocation("foo");
       assert config.getLocation().equals("foo");




More information about the jbosscache-commits mailing list
--- core/branches/flat/src/main/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfig.java	2009-03-02 18:47:12 UTC (rev 7822)
+++ core/branches/flat/src/main/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfig.java	2009-03-02 18:52:30 UTC (rev 7823)
@@ -6,8 +6,8 @@
  * Configures {@link org.horizon.loader.bdbje.BdbjeCacheStore}.  This allows you to tune a number of characteristics of
  * the {@link BdbjeCacheStore}.
  * <p/>
  * <ul> <li><tt>location</tt> - a location on disk where the store can write databases.  This defaults to
  * <tt>${java.io.tmpdir}</tt></li> <li><tt>purgeSynchronously</tt> - whether {@link
  * org.horizon.loader.CacheStore#purgeExpired()} calls happen synchronously or not.  By default, this is set to
  * <tt>false</tt>.</li> <li><tt>lockAcquistionTimeout</tt> - the length of time, in milliseconds, to wait for locks
  * before timing out and throwing an exception.  By default, this is set to <tt>60000</tt>.</li>
@@ -19,7 +19,7 @@
  * @since 1.0
  */
 public class BdbjeCacheStoreConfig extends AbstractCacheLoaderConfig {
-   private String location = System.getProperty("java.io.tmpdir");
+   private String location = "Horizon-BdbjeCacheStore";
    private boolean purgeSynchronously;
    private long lockAcquistionTimeout = 60 * 1000;
    private int maxTxRetries = 5;
@@ -6,8 +6,8 @@
  * the {@link BdbjeCacheStore}.
  * <p/>
- * <ul> <li><tt>location</tt> - a location on disk where the store can write databases.  This defaults to
- * <tt>${java.io.tmpdir}</tt></li> <li><tt>purgeSynchronously</tt> - whether {@link
+ * <ul> <li><tt>location</tt> - a location on disk where the store can write internal files.  This defaults to
+ * <tt>Horizon-BdbjeCacheStore</tt> in the current working directory.</li> <li><tt>purgeSynchronously</tt> - whether {@link
  * org.horizon.loader.CacheStore#purgeExpired()} calls happen synchronously or not.  By default, this is set to
  * <tt>false</tt>.</li> <li><tt>lockAcquistionTimeout</tt> - the length of time, in milliseconds, to wait for locks

Modified: core/branches/flat/src/test/java/org/horizon/loader/bdbje/BdbjeCacheStoreConfigTest.java
===================================================================